rename NextDeclInScope to NextDeclInContext, since the pointer
points within contexts not scopes.


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@67919 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/AST/DeclBase.cpp b/lib/AST/DeclBase.cpp
index 72ac555..634c86e 100644
--- a/lib/AST/DeclBase.cpp
+++ b/lib/AST/DeclBase.cpp
@@ -282,15 +282,15 @@
   if (DeclContext *DC = dyn_cast<DeclContext>(this))
     DC->decls_begin()->Destroy(C);
 
   // Observe the unrolled recursion.  By setting N->NextDeclInScope = 0x0
   // within the loop, only the Destroy method for the first Decl
   // will deallocate all of the Decls in a chain.
   
-  Decl* N = NextDeclInScope;
+  Decl* N = getNextDeclInContext();
   
   while (N) {
-    Decl* Tmp = N->NextDeclInScope;
-    N->NextDeclInScope = 0;
+    Decl* Tmp = N->getNextDeclInContext();
+    N->NextDeclInContext = 0;
     N->Destroy(C);
     N = Tmp;
   }  
@@ -541,7 +541,7 @@
     if (DeclKind >= Decl::TagFirst && DeclKind <= Decl::TagLast) {
       // If this is a tag type that has a definition or is currently
       // being defined, that definition is our primary context.
-      if (const TagType *TagT = cast<TagDecl>(this)->TypeForDecl->getAsTagType())
+      if (const TagType *TagT =cast<TagDecl>(this)->TypeForDecl->getAsTagType())
         if (TagT->isBeingDefined() || 
             (TagT->getDecl() && TagT->getDecl()->isDefinition()))
           return TagT->getDecl();
@@ -568,11 +568,11 @@
 void DeclContext::addDecl(Decl *D) {
   assert(D->getLexicalDeclContext() == this &&
          "Decl inserted into wrong lexical context");
-  assert(!D->NextDeclInScope && D != LastDecl && 
+  assert(!D->getNextDeclInContext() && D != LastDecl && 
          "Decl already inserted into a DeclContext");
 
   if (FirstDecl) {
-    LastDecl->NextDeclInScope = D;
+    LastDecl->NextDeclInContext = D;
     LastDecl = D;
   } else {
     FirstDecl = LastDecl = D;
@@ -282,15 +282,15 @@
     DC->decls_begin()->Destroy(C);
 
-  // Observe the unrolled recursion.  By setting N->NextDeclInScope = 0x0
+  // Observe the unrolled recursion.  By setting N->NextDeclInContext = 0x0
   // within the loop, only the Destroy method for the first Decl
   // will deallocate all of the Decls in a chain.